/*
 * spi.h
 */

#ifndef SPI_H_
#define SPI_H_

#include <inttypes.h>
#include "../mss_gpio/mss_gpio.h"

#define  FABRIC_BASE_ADDR 0x40050000

/**
 * Initialize the SPI peripheral:
 * - set the clock rate
 * - set the clock polarity to active low
 * - set the clock edge to data valid on leading edge
 * - Configure the Chip Select IO line. We use MSS GPIO15 for this
 *   as the radio driver needs special chip select capabilities.
 *   You can safely ignore any chip select capabilities the CoreSPI
 *   core provides.
 */
void spi_init();

/**
 * Return the value of the chip select line, i.e. 1 if
 * the line is high, or 0 if the line is low.
 */
uint8_t CSN_get();

/**
 * Set the chip select line high. Use GPIO15 of the MSS for this.
 */
void CSN_set();

/**
 * Set the chip select line low. Use GPIO15 of the MSS for this.
 */
void CSN_clr();

/**
 * Write a byte onto the SPI bus, and return the concurrently read byte.
 * This function should block until the write/read is finished. You can
 * achieve this by polling the BUSY status of the CoreSPI component.
 * Note: I also tried to use the other status bytes (RX Ready or TX Empty).
 * But for some reason they didn't work. BUSY however does work.
 */
uint8_t SpiByte_write(uint8_t byte);

#endif /* SPI_H_ */
